@@ -1,23 +1,24 @@
 
 
-#' @title Recorded sunspots births during 1872--2018
+#' @title Recorded sunspots births/deaths during 1872--2018
 #'
 #' @description Processed version of the
-#' \href{http://fenyi.solarobs.csfk.mta.hu/DPD/}{
-#' Debrecen Photoheliographic Data (DPD)} sunspot catalogue and the
+#' \href{http://fenyi.solarobs.epss.hun-ren.hu/DPD/}{
+#' Debrecen Photoheliographic Data (DPD)} sunspot catalog and the
 #' revised version of the
-#' \href{http://fenyi.solarobs.csfk.mta.hu/GPR/}{
-#' Greenwich Photoheliographic Results (GPR)} sunspot catalogue. The two
+#' \href{http://fenyi.solarobs.epss.hun-ren.hu/GPR/}{
+#' Greenwich Photoheliographic Results (GPR)} sunspot catalog. The two
 #' sources contain the records of sunspots appeared during 1872--2018 (GPR for
 #' 1872--1976; DPD for 1974--2018).
 #'
 #' Sunspots appear in groups and have a variable lifetime. This dataset has
-#' been processed to account only for the \emph{births} or emergences
-#' (first observations) of \emph{groups} of sunspots.
+#' been processed to account for the \emph{births} (first observations) and
+#' \emph{deaths} (last observations) of \emph{groups} of sunspots.
 #'
 #' @docType data
 #' @format A data frame with 51303 rows and 6 variables:
 #' \describe{
+#'   \item{NOAA}{NOAA identifier of the group of sunspots, a factor.}
 #'   \item{date}{UTC date, as \code{\link[base:DateTimeClasses]{POSIXct}}, of
 #'   the first observation of a group of sunspots.}
 #'   \item{cycle}{\href{https://en.wikipedia.org/wiki/List_of_solar_cycles}{
@@ -43,26 +44,26 @@
 #' with \eqn{(0, 0, 1)} denoting the north pole.
 #'
 #' The DPD data has
-#' \href{http://fenyi.solarobs.csfk.mta.hu/ftp/pub/DPD/README.txt}{
+#' \href{http://fenyi.solarobs.epss.hun-ren.hu/ftp/pub/DPD/README.txt}{
 #' different states} of completeness and quality control. The
 #' longest span of "final complete data" (no missing observation days and
 #' the data has undergone a systematic quality control) is from 2005 to 2015.
 #'
 #' The data has been preprocessed using the following pipeline:
 #' \enumerate{
-#'   \item Retrieve data from the GPR and DPD sunspot catalogues.
+#'   \item Retrieve data from the GPR and DPD sunspot catalogs.
 #'   \item Omit observations with \code{NA}s in the sunspot positions.
 #'   \item Filter for sunspot groups.
 #'   \item Relabel the NOAA identifier for the sunspot group for records
 #'   before 1974, prefixing the "GPR" string. Otherwise, very different groups
-#'   of sunspots from the two catalogues may share the same identifier.
+#'   of sunspots from the two catalogs may share the same identifier.
 #'   \item Keep only the first row of each NOAA instance, the first-ever
 #'   observation of each sunspot group.
 #' }
 #' The script performing the preprocessing is available at
-#' \href{https://github.com/egarpor/rotasym/blob/master/data-raw/sunspots-births.R}{
-#' \code{sunspots-births.R}}
-#' @source \url{http://fenyi.solarobs.csfk.mta.hu}
+#' \href{https://github.com/egarpor/rotasym/blob/master/data-raw/sunspots.R}{
+#' \code{sunspots.R}}
+#' @source \url{http://fenyi.solarobs.epss.hun-ren.hu}
 #' @author Data processed by Eduardo García-Portugués, Davy Paindaveine, and
 #' Thomas Verdebout from the original sources.
 #' @references
@@ -75,36 +76,32 @@
 #' sunspot catalogues. \emph{Monthly Notices of the Royal Astronomical
 #' Society}, 465(2):1259--1273. \doi{10.1093/mnras/stw2667}
 #' @examples
-#' # Load data
+#' # Load births data of the 23rd cycle
 #' data("sunspots_births")
+#' sp_bir_23 <- subset(sunspots_births, cycle == 23)
 #'
 #' # Transform to Cartesian coordinates
-#' sunspots_births$X <-
-#'   cbind(cos(sunspots_births$phi) * cos(sunspots_births$theta),
-#'         cos(sunspots_births$phi) * sin(sunspots_births$theta),
-#'         sin(sunspots_births$phi))
+#' sp_bir_23$X_bir <-
+#'   cbind(cos(sp_bir_23$phi) * cos(sp_bir_23$theta),
+#'         cos(sp_bir_23$phi) * sin(sp_bir_23$theta),
+#'         sin(sp_bir_23$phi))
 #'
-#' # Plot data associated to the 23rd cycle
-#' sunspots_23 <- subset(sunspots_births, cycle == 23)
-#' n <- nrow(sunspots_23$X)
-#' if (requireNamespace("rgl")) {
-#'   rgl::plot3d(0, 0, 0, xlim = c(-1, 1), ylim = c(-1, 1), zlim = c(-1, 1),
-#'               radius = 1, type = "s", col = "lightblue", alpha = 0.25,
-#'               lit = FALSE)
-#' }
+#' # Plot births
 #' n_cols <- 100
-#' cuts <- cut(x = sunspots_23$date, include.lowest = TRUE,
-#'             breaks = quantile(sunspots_23$date,
-#'                              probs = seq(0, 1, l = n_cols + 1)))
-#' if (requireNamespace("rgl")) {
-#'   rgl::points3d(sunspots_23$X, col = viridisLite::viridis(n_cols)[cuts])
-#' }
+#' cuts <- cut(x = sp_bir_23$date, include.lowest = TRUE,
+#'             breaks = quantile(sp_bir_23$date,
+#'                               probs = seq(0, 1, l = n_cols + 1)))
+#' scatterplot3d::scatterplot3d(sp_bir_23$X_bir, xlim = c(-1, 1),
+#'                              ylim = c(-1, 1), zlim = c(-1, 1),
+#'                              color = viridisLite::viridis(n_cols)[cuts],
+#'                              pch = 16, cex.symbols = 0.5, xlab = "",
+#'                              ylab = "", zlab = "", angle = 30)
 #' # Spörer's law: sunspots at the beginning of the solar cycle (dark blue
-#' # color) tend to appear at higher latitutes, gradually decreasing to the
+#' # color) tend to appear at higher latitudes, gradually decreasing to the
 #' # equator as the solar cycle advances (yellow color)
 #'
 #' # Estimation of the density of the cosines
-#' V <- cosines(X = sunspots_23$X, theta = c(0, 0, 1))
+#' V <- cosines(X = sp_bir_23$X_bir, theta = c(0, 0, 1))
 #' h <- bw.SJ(x = V, method = "dpi")
 #' plot(kde <- density(x = V, bw = h, n = 2^13, from = -1, to = 1), col = 1,
 #'      xlim = c(-1, 1), ylim = c(0, 3), axes = FALSE, main = "",
@@ -119,15 +116,15 @@
 #'        lwd = 2, col = c(1, viridisLite::viridis(12)[c(3, 8)]))
 #'
 #' # Density for the observations within the initial 25% of the cycle
-#' part1 <- sunspots_23$date < quantile(sunspots_23$date, 0.25)
-#' V1 <- cosines(X = sunspots_23$X[part1, ], theta = c(0, 0, 1))
+#' part1 <- sp_bir_23$date < quantile(sp_bir_23$date, 0.25)
+#' V1 <- cosines(X = sp_bir_23$X[part1, ], theta = c(0, 0, 1))
 #' h1 <- bw.SJ(x = V1, method = "dpi")
 #' lines(kde1 <- density(x = V1, bw = h1, n = 2^13, from = -1, to = 1),
 #'       col = viridisLite::viridis(12)[3], lwd = 2)
 #'
 #' # Density for the observations within the final 25% of the cycle
-#' part2 <- sunspots_23$date > quantile(sunspots_23$date, 0.75)
-#' V2 <- cosines(X = sunspots_23$X[part2, ], theta = c(0, 0, 1))
+#' part2 <- sp_bir_23$date > quantile(sp_bir_23$date, 0.75)
+#' V2 <- cosines(X = sp_bir_23$X[part2, ], theta = c(0, 0, 1))
 #' h2 <- bw.SJ(x = V2, method = "dpi")
 #' lines(kde2 <- density(x = V2, bw = h2, n = 2^13, from = -1, to = 1),
 #'       col = viridisLite::viridis(12)[8], lwd = 2)
@@ -158,4 +155,41 @@
 #' modes <- c(kde$x[kde$x < 0][which.max(kde$y[kde$x < 0])],
 #'            kde$x[kde$x > 0][which.max(kde$y[kde$x > 0])])
 #' 90 - acos(modes) / pi * 180
+#'
+#' # Load deaths data of the 23rd cycle
+#' data("sunspots_deaths")
+#' sp_dea_23 <- subset(sunspots_deaths, cycle == 23)
+#'
+#' # Transform to Cartesian coordinates
+#' sp_dea_23$X_dea <-
+#'   cbind(cos(sp_dea_23$phi) * cos(sp_dea_23$theta),
+#'         cos(sp_dea_23$phi) * sin(sp_dea_23$theta),
+#'         sin(sp_dea_23$phi))
+#'
+#' # Match births and deaths, and exclude single-day observations
+#' sp_23 <- dplyr::full_join(sp_bir_23, sp_dea_23, by = "NOAA",
+#'                           suffix = c("_bir", "_dea"))
+#' sp_23 <- sp_23[sp_23$date_bir != sp_23$date_dea, ]
+#'
+#' # Plot births and deaths associated to the 23rd cycle, and color according
+#' # to movement direction of sunspots
+#' sc <- scatterplot3d::scatterplot3d(sp_23$X_bir, xlim = c(-1, 1),
+#'                                    ylim = c(-1, 1), zlim = c(-1, 1),
+#'                                    color = 1, cex.symbols = 0.1,
+#'                                    pch = 16, xlab = "", ylab = "", zlab = "",
+#'                                    angle = 30)
+#' sc$points3d(sp_23$X_dea, col = 1, cex = 0.1)
+#' for (i in seq_len(nrow(sp_23))) {
+#'   sc$points3d(rbind(sp_23$X_bir[i, ], sp_23$X_dea[i, ]),
+#'               col = ifelse((sp_23$theta_bir[i] - sp_23$theta_dea[i]) %%
+#'                             (2 * pi) < pi, 2, 3), type = "l")
+#' }
+#' @name sunspots
+
+
+#' @rdname sunspots
 "sunspots_births"
+
+
+#' @rdname sunspots
+"sunspots_deaths"
